aind\_data\_schema.ophys package
================================

Submodules
----------

aind\_data\_schema.ophys.ophys\_rig module
------------------------------------------

.. automodule:: aind_data_schema.ophys.ophys_rig
   :members:
   :undoc-members:
   :show-inheritance:

aind\_data\_schema.ophys.ophys\_session module
----------------------------------------------

.. automodule:: aind_data_schema.ophys.ophys_session
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: aind_data_schema.ophys
   :members:
   :undoc-members:
   :show-inheritance:
